Projects — Renga 0.1.0.dev20170915 documentation

Join us on GitHub

# Projects

Manage projects on the server.

class `renga.models.projects.` `ProjectCollection`(client=None)

  Represent projects on the server.

  Example

  Create a project and check its name.

      >>> project = client.projects.create(name='test-project')
      >>> project.name
      'test-project'

  Create representation of objects on the server.

  class `Meta`

    Information about individual projects.

    `model`

      alias of `Project`

  `create`(name=None, **kwargs)

    Create new project.

    Parameters: | name – The name of the project.
    Returns: | An instance of newly create project.
    Return type: | Project

  `list`()

    Return list if the collection is iterable.

## Project objects

class `renga.models.projects.` `Project`

  Represent a project.

  Create representation of object on the server.

  `id`

    The identifier of the object.

  `name`

    The name of the project.